@@ -106,7 +106,7 @@ impl<R: RngCore> Scru128Generator<R> {
                 #[cfg(feature = "log")]
                 log::info!("counter limit reached; will wait until clock goes forward");
                 let mut n_clock_check = 0;
-                while ts_now >= self.ts_last_gen {
+                while ts_now <= self.ts_last_gen {
                     ts_now = get_msec_unixts();
                     n_clock_check += 1;
                     if n_clock_check > self.n_clock_check_max {
